@@ -1,9 +1,10 @@
 context("mdsr")
 
 test_that("scidb works", {
+  skip_on_cran()
   x <- dbConnect_scidb("airlines")
   expect_s4_class(x, "DBIObject")
-  expect_output(print(x), "MySQLConnection")
+  expect_output(print(x), "MariaDBConnection")
   
   suppressWarnings(y <- tbl(x, "airports"))
   expect_s3_class(y, c("tbl_dbi", "tbl_sql", "tbl"))
@@ -18,6 +19,7 @@ test_that("scidb works", {
     1
   )
   expect_length(DBI::dbListTables(x), 4)
+  DBI::dbDisconnect(x)
 })
 
 test_that("download functions work", {
@@ -38,7 +40,7 @@ test_that("save_webshot works", {
       addTiles() %>%
       addMarkers(lng = 174.768, lat = -36.852, popup = "The birthplace of R")
     png <- save_webshot(x, tempfile())
-    expect_is(png, "fs_path")
+    expect_s3_class(png, "fs_path")
 #    expect_true(file.exists(png))
   }
 })
